@@ -1,6 +1,3 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 import os
 
 extensions = [
@@ -24,7 +21,7 @@ master_doc = "index"
 project = "decaylanguage"
 year = "2018"
 author = "Henry Fredrick Schreiner III"
-copyright = "{}, {}".format(year, author)
+copyright = f"{year}, {author}"
 version = release = "0.2.0"
 
 pygments_style = "trac"
@@ -45,7 +42,7 @@ html_split_index = False
 html_sidebars = {
     "**": ["searchbox.html", "globaltoc.html", "sourcelink.html"],
 }
-html_short_title = "{}-{}".format(project, version)
+html_short_title = f"{project}-{version}"
 
 napoleon_use_ivar = True
 napoleon_use_rtype = False
