@@ -1,4 +1,7 @@
-# -*- coding: utf-8 -*-
 from .amplitudechain import LS, AmplitudeChain
 
 __all__ = ("LS", "AmplitudeChain")
+
+
+def __dir__():
+    return __all__
