@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) 2018-2021, Eduardo Rodrigues and Henry Schreiner.
+# Copyright (c) 2018-2022, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/decaylanguage for details.
@@ -9,8 +8,6 @@ A general base class representing decays.
 """
 
 
-from __future__ import absolute_import, division, print_function
-
 import warnings
 from itertools import product
 
@@ -26,10 +23,10 @@ except ImportError:
 
 
 @attr.s(slots=True)
-class ModelDecay(object):
+class ModelDecay:
     """
     This describes a decay very generally, with search and print features.
-    Subclassed for futher usage.
+    Subclassed for further usage.
     """
 
     particle = attr.ib()
@@ -123,5 +120,12 @@ class ModelDecay(object):
             self._add_nodes(d)
             return d
 
-        def _repr_svg_(self):
-            return self._make_graphviz()._repr_svg_()
+        def _repr_mimebundle_(self, include=None, exclude=None, **kwargs):
+            try:
+                return self._make_graphviz()._repr_mimebundle_(
+                    include=include, exclude=exclude, **kwargs
+                )
+            except AttributeError:
+                return {
+                    "image/svg+xml": self._make_graphviz()._repr_svg_()
+                }  # for graphviz < 0.19
