@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from .errors import LineFailure
 from .particleutils import charge_conjugate_name
 from .utilities import filter_lines, iter_flatten, split
@@ -11,3 +9,7 @@ __all__ = (
     "filter_lines",
     "charge_conjugate_name",
 )
+
+
+def __dir__():
+    return __all__
