@@ -1,12 +1,10 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) 2018-2021, Eduardo Rodrigues and Henry Schreiner.
+# Copyright (c) 2018-2022, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/decaylanguage for details.
 
-from __future__ import absolute_import
 
-import sys
+from functools import lru_cache
 
 from particle import Particle
 from particle.converters import (
@@ -16,14 +14,7 @@ from particle.converters import (
 )
 from particle.exceptions import MatchingIDNotFound
 
-if sys.version_info < (3,):
-    from cachetools import LFUCache, cached
-
-    cacher = cached(cache=LFUCache(maxsize=64))
-else:
-    from functools import lru_cache
-
-    cacher = lru_cache(maxsize=64)
+cacher = lru_cache(maxsize=64)
 
 
 @cacher
@@ -62,7 +53,7 @@ def charge_conjugate_name(name, pdg_name=False):
             # Convert the EvtGen name back to a PDG name, to match input type
             return EvtGen2PDGNameMap[ccname]
         except MatchingIDNotFound:  # Catch issue in PDG2EvtGenNameMap matching
-            return "ChargeConj({})".format(name)
+            return f"ChargeConj({name})"
 
     # Dealing only with EvtGen names at this stage
     try:
@@ -71,4 +62,4 @@ def charge_conjugate_name(name, pdg_name=False):
         try:
             return EvtGenName2PDGIDBiMap[-EvtGenName2PDGIDBiMap[name]]
         except Exception:
-            return "ChargeConj({})".format(name)
+            return f"ChargeConj({name})"
