@@ -1,18 +1,11 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) 2018-2021, Eduardo Rodrigues and Henry Schreiner.
+# Copyright (c) 2018-2022, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/decaylanguage for details.
 
-import sys
+from pathlib import Path
 
 import pytest
-
-try:
-    from pathlib2 import Path
-except ImportError:
-    from pathlib import Path
-
 from lark import Token, Tree
 
 from decaylanguage.dec.dec import (
@@ -28,10 +21,6 @@ from decaylanguage.dec.dec import (
 )
 from decaylanguage.dec.enums import known_decay_models
 
-if sys.version_info < (3,):
-    FileNotFoundError = IOError
-
-
 DIR = Path(__file__).parent.resolve()
 
 
