@@ -1,18 +1,14 @@
-# -*- coding: utf-8 -*-
-# Copyright (c) 2018-2021, Eduardo Rodrigues and Henry Schreiner.
+# Copyright (c) 2018-2022, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/decaylanguage for details.
 
-from decaylanguage.modeling.ampgen2goofit import ampgen2goofit
-
-try:
-    from pathlib2 import Path
-except ImportError:
-    from pathlib import Path
+from pathlib import Path
 
 import pytest
 
+from decaylanguage.modeling.ampgen2goofit import ampgen2goofit
+
 DIR = Path(__file__).parent.resolve()
 
 
